@@ -2,72 +2,58 @@
 <context>
     <name>AppItemMenu</name>
     <message>
-        <location filename="../../qml/AppItemMenu.qml" line="34"/>
         <source>Open</source>
         <translation>Ouvrir</translation>
     </message>
     <message>
-        <location filename="../../qml/AppItemMenu.qml" line="46"/>
         <source>Pin to Top</source>
         <translation>Épingler en haut</translation>
     </message>
     <message>
-        <location filename="../../qml/AppItemMenu.qml" line="55"/>
         <source>Move to Top</source>
         <translation>Déplacer vers le haut</translation>
     </message>
     <message>
-        <location filename="../../qml/AppItemMenu.qml" line="65"/>
         <source>Remove from favorites</source>
         <translation>Retirer des favoris</translation>
     </message>
     <message>
-        <location filename="../../qml/AppItemMenu.qml" line="65"/>
         <source>Add to favorites</source>
         <translation>Ajouter aux favoris</translation>
     </message>
     <message>
-        <location filename="../../qml/AppItemMenu.qml" line="80"/>
         <source>Remove from desktop</source>
         <translation>Supprimer du bureau</translation>
     </message>
     <message>
-        <location filename="../../qml/AppItemMenu.qml" line="80"/>
         <source>Send to desktop</source>
         <translation>Envoyer sur le bureau</translation>
     </message>
     <message>
-        <location filename="../../qml/AppItemMenu.qml" line="91"/>
         <source>Remove from dock</source>
         <translation>Supprimer du dock</translation>
     </message>
     <message>
-        <location filename="../../qml/AppItemMenu.qml" line="91"/>
         <source>Send to dock</source>
         <translation>Épingler au dock</translation>
     </message>
     <message>
-        <location filename="../../qml/AppItemMenu.qml" line="103"/>
         <source>Remove from startup</source>
         <translation>Supprimer du démarrage</translation>
     </message>
     <message>
-        <location filename="../../qml/AppItemMenu.qml" line="103"/>
         <source>Add to startup</source>
         <translation>Ajouter au démarrage</translation>
     </message>
     <message>
-        <location filename="../../qml/AppItemMenu.qml" line="111"/>
         <source>Use a proxy</source>
         <translation>Utiliser un proxy</translation>
     </message>
     <message>
-        <location filename="../../qml/AppItemMenu.qml" line="120"/>
         <source>Disable display scaling</source>
         <translation>Désactivez la mise à l&apos;échelle de l&apos;affichage</translation>
     </message>
     <message>
-        <location filename="../../qml/AppItemMenu.qml" line="127"/>
         <source>Uninstall</source>
         <translation>Désinstaller</translation>
     </message>
@@ -75,17 +61,14 @@
 <context>
     <name>BottomBar</name>
     <message>
-        <location filename="../../qml/windowed/BottomBar.qml" line="33"/>
         <source>Power</source>
         <translation>Alimentation</translation>
     </message>
     <message>
-        <location filename="../../qml/windowed/BottomBar.qml" line="62"/>
         <source>Search</source>
         <translation>Rechercher</translation>
     </message>
     <message>
-        <location filename="../../qml/windowed/BottomBar.qml" line="109"/>
         <source>Full-screen Mode</source>
         <translation>Mode plein écran</translation>
     </message>
@@ -93,12 +76,10 @@
 <context>
     <name>DummyAppItemMenu</name>
     <message>
-        <location filename="../../qml/DummyAppItemMenu.qml" line="27"/>
         <source>Install</source>
         <translation>Installer</translation>
     </message>
     <message>
-        <location filename="../../qml/DummyAppItemMenu.qml" line="34"/>
         <source>Remove</source>
         <translation>Retirer</translation>
     </message>
@@ -106,7 +87,6 @@
 <context>
     <name>FrequentlyUsedView</name>
     <message>
-        <location filename="../../qml/windowed/FrequentlyUsedView.qml" line="36"/>
         <source>Frequently Used</source>
         <translation>Utilisé souvent</translation>
     </message>
@@ -114,7 +94,6 @@
 <context>
     <name>FullscreenFrame</name>
     <message>
-        <location filename="../../qml/FullscreenFrame.qml" line="254"/>
         <source>Window Mode</source>
         <translation>Mode fenêtre</translation>
     </message>
@@ -122,72 +101,58 @@
 <context>
     <name>Main</name>
     <message>
-        <location filename="../../qml/Main.qml" line="22"/>
         <source>Internet</source>
         <translation>Internet</translation>
     </message>
     <message>
-        <location filename="../../qml/Main.qml" line="24"/>
         <source>Chat</source>
         <translation>Discussion</translation>
     </message>
     <message>
-        <location filename="../../qml/Main.qml" line="26"/>
         <source>Music</source>
         <translation>Musique</translation>
     </message>
     <message>
-        <location filename="../../qml/Main.qml" line="28"/>
         <source>Video</source>
         <translation>Vidéo</translation>
     </message>
     <message>
-        <location filename="../../qml/Main.qml" line="30"/>
         <source>Graphics</source>
         <translation>Graphisme</translation>
     </message>
     <message>
-        <location filename="../../qml/Main.qml" line="32"/>
         <source>Games</source>
         <translation>Jeux</translation>
     </message>
     <message>
-        <location filename="../../qml/Main.qml" line="34"/>
         <source>Office</source>
         <translation>Bureautique</translation>
     </message>
     <message>
-        <location filename="../../qml/Main.qml" line="36"/>
         <source>Reading</source>
         <translation>Lecture</translation>
     </message>
     <message>
-        <location filename="../../qml/Main.qml" line="38"/>
         <source>Development</source>
         <translation>Développement</translation>
     </message>
     <message>
-        <location filename="../../qml/Main.qml" line="40"/>
         <source>System</source>
         <translation>Système</translation>
     </message>
     <message>
-        <location filename="../../qml/Main.qml" line="42"/>
         <source>Others</source>
         <translation>Autres</translation>
     </message>
     <message>
-        <location filename="../../qml/Main.qml" line="400"/>
         <source>Are you sure you want to uninstall &quot;%1&quot;?</source>
         <translation>Êtes-vous sûr de vouloir désinstaller &quot;%1&quot; ?</translation>
     </message>
     <message>
-        <location filename="../../qml/Main.qml" line="412"/>
         <source>Cancel</source>
         <translation>Annuler</translation>
     </message>
     <message>
-        <location filename="../../qml/Main.qml" line="426"/>
         <source>Confirm</source>
         <translation>Confirmer</translation>
     </message>
@@ -195,7 +160,6 @@
 <context>
     <name>RecentlyInstalledView</name>
     <message>
-        <location filename="../../qml/windowed/RecentlyInstalledView.qml" line="34"/>
         <source>Recently Installed</source>
         <translation>Installé récemment</translation>
     </message>
@@ -203,13 +167,10 @@
 <context>
     <name>SearchResultView</name>
     <message>
-        <location filename="../../qml/windowed/SearchResultView.qml" line="37"/>
         <source>All Apps</source>
         <translation>Toutes les application</translation>
     </message>
     <message>
-        <location filename="../../qml/FullscreenFrame.qml" line="557"/>
-        <location filename="../../qml/windowed/SearchResultView.qml" line="102"/>
         <source>No search results</source>
         <translation>Aucun résultat trouvé</translation>
     </message>
@@ -217,47 +178,38 @@
 <context>
     <name>SideBar</name>
     <message>
-        <location filename="../../qml/windowed/SideBar.qml" line="40"/>
         <source>Free sorting</source>
         <translation>Tri libre</translation>
     </message>
     <message>
-        <location filename="../../qml/windowed/SideBar.qml" line="54"/>
         <source>Sort by category</source>
         <translation>Trier par catégorie</translation>
     </message>
     <message>
-        <location filename="../../qml/windowed/SideBar.qml" line="66"/>
         <source>Sort by name</source>
         <translation>Trier par nom</translation>
     </message>
     <message>
-        <location filename="../../qml/windowed/SideBar.qml" line="90"/>
         <source>Sorting Mode</source>
         <translation>Mode de tri</translation>
     </message>
     <message>
-        <location filename="../../qml/windowed/SideBar.qml" line="145"/>
         <source>Computer</source>
         <translation>Ordinateur</translation>
     </message>
     <message>
-        <location filename="../../qml/windowed/SideBar.qml" line="156"/>
         <source>Pictures</source>
         <translation>Images</translation>
     </message>
     <message>
-        <location filename="../../qml/windowed/SideBar.qml" line="167"/>
         <source>Documents</source>
         <translation>Documents</translation>
     </message>
     <message>
-        <location filename="../../qml/windowed/SideBar.qml" line="178"/>
         <source>Desktop</source>
         <translation>Bureau</translation>
     </message>
     <message>
-        <location filename="../../qml/windowed/SideBar.qml" line="189"/>
         <source>Control Center</source>
         <translation>Centre de contrôle</translation>
     </message>
@@ -265,77 +217,62 @@
 <context>
     <name>launcheritem</name>
     <message>
-        <location filename="../package/launcheritem.qml" line="111"/>
         <source>Internet</source>
         <translation>Internet</translation>
     </message>
     <message>
-        <location filename="../package/launcheritem.qml" line="113"/>
         <source>Chat</source>
         <translation>Discussion</translation>
     </message>
     <message>
-        <location filename="../package/launcheritem.qml" line="115"/>
         <source>Music</source>
         <translation>Musique</translation>
     </message>
     <message>
-        <location filename="../package/launcheritem.qml" line="117"/>
         <source>Video</source>
         <translation>Vidéo</translation>
     </message>
     <message>
-        <location filename="../package/launcheritem.qml" line="119"/>
         <source>Graphics</source>
         <translation>Graphisme</translation>
     </message>
     <message>
-        <location filename="../package/launcheritem.qml" line="121"/>
         <source>Games</source>
         <translation>Jeux</translation>
     </message>
     <message>
-        <location filename="../package/launcheritem.qml" line="123"/>
         <source>Office</source>
         <translation>Bureautique</translation>
     </message>
     <message>
-        <location filename="../package/launcheritem.qml" line="125"/>
         <source>Reading</source>
         <translation>Lecture</translation>
     </message>
     <message>
-        <location filename="../package/launcheritem.qml" line="127"/>
         <source>Development</source>
         <translation>Développement</translation>
     </message>
     <message>
-        <location filename="../package/launcheritem.qml" line="129"/>
         <source>System</source>
         <translation>Système</translation>
     </message>
     <message>
-        <location filename="../package/launcheritem.qml" line="131"/>
         <source>Others</source>
         <translation>Autres</translation>
     </message>
     <message>
-        <location filename="../package/launcheritem.qml" line="162"/>
         <source>launchpad</source>
         <translation>Launchpad</translation>
     </message>
     <message>
-        <location filename="../package/launcheritem.qml" line="309"/>
         <source>Are you sure you want to uninstall &quot;%1&quot;?</source>
         <translation>Êtes-vous sûr de vouloir désinstaller &quot;%1&quot; ?</translation>
     </message>
     <message>
-        <location filename="../package/launcheritem.qml" line="321"/>
         <source>Cancel</source>
         <translation>Annuler</translation>
     </message>
     <message>
-        <location filename="../package/launcheritem.qml" line="335"/>
         <source>Confirm</source>
         <translation>Confirmer</translation>
     </message>
