@@ -7,6 +7,10 @@
 #include <QtQml/qqml.h>
 #include <QSortFilterProxyModel>
 
+namespace Dtk::Core {
+class DConfig;
+}
+
 class SearchFilterProxyModel : public QSortFilterProxyModel
 {
     Q_OBJECT
@@ -29,6 +33,13 @@ public:
     // QSortFilterProxyModel interface
 protected:
     bool filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const override;
+    bool lessThan(const QModelIndex &source_left, const QModelIndex &source_right) const override;
+
 private:
     explicit SearchFilterProxyModel(QObject *parent = nullptr);
+
+    int calculateWeight(const QModelIndex &modelIndex) const;
+
+    Dtk::Core::DConfig *m_dconfig;
+    bool m_searchPackageEnabled;
 };
